import React, { useState, useEffect, useMemo, useRef } from 'react';
import AutoTable from '@/components/AutoTable';
import useKeepAlive from "@/components/useKeepAlive";
import PremButton from '@/components/PremButton';
import getcolumns from "./columns";
import { useRequest } from "ahooks";
import { doFetch } from '@/utils/doFetch';
function Allot() {
  let actionRef = useRef();
  const [tabKey, setTabKey] = useState('1');
  const { runAsync } = useRequest(doFetch, {
    manual: true,
    onSuccess: (res, params) => {
      if (res.code == '0000') {
        actionRef?.current?.reload();
      }
    }
  });
  const tabList = useMemo(() => {
    return getcolumns();
  }, [tabKey]);
  const columns = useMemo(() => {
    let defcolumn = getcolumns().filter((it) => it.key == tabKey)[0]?.columns ?? [];
    return tabKey === '2' ? defcolumn : defcolumn.concat({
      title: "操作",
      valueType: "option",
      width: 80,
      render: (text, row, _, action) => rightExtra(text, row, _, action),
    });
  }, [tabKey]);
  const pathconfig = useMemo(() => {
    let defpath = getcolumns().filter((it) => it.key == tabKey)[0]?.pathconfig ?? {};
    return defpath;
  }, [tabKey]);
  const rightExtra = (text, row, _, action) => {
    return [
      <PremButton
        key="delete"
        pop={{
          title: "是否关闭该调拨单?",
          okText: "确认",
          cancelText: "取消",
          onConfirm: async () => {
            await runAsync({
              url: "/ta_wms_workmanship/pmEmptyTransfer/closeTask",
              params: { id: row.id },
            });
          },
        }}
        btn={{
          size: "small",
          danger: true,
        }}
      >
        关单
      </PremButton>,
    ];
  };




  return <div>
    <AutoTable
      pagetitle='空托盘调拨'
      columns={columns}
      path={pathconfig?.list}
      actionRef={actionRef}
      resizeable={false}
      tabList={tabList}
      tabKey={tabKey}
      onTabChange={(key) => {
        setTabKey(key);
      }}
    />
  </div>
}

export default useKeepAlive(Allot);